==> linpsk_0.6.2.orig.tar.gz: linpsk-0.6.2/linpsk/main.cpp <==
/***************************************************************************
                          main.cpp  -  description
                             -------------------
    begin                : Die Mai  8 21:20:50 CEST 2001
    copyright            : (C) 2001 by Volker Schroer
    email                : dl1ksv@gmx.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include <qapplication.h>
#include <qfont.h>
#include <qstring.h>
#include <qtextcodec.h>
#include <qtranslator.h>

#include "linpsk.h"

#include "parameter.h"
Parameter settings;

int main(int argc, char *argv[])
{
QString c;

c="LinPsk Version ";
c +=VERSION;
	if (settings.DemoMode)
	c += " -- DemoMode";
	else
	c += " -- "+settings.callsign;
  QApplication a(argc, argv);
  a.setFont(QFont("helvetica", 12));
  QTranslator tor( 0 );
  // set the location where your .qm files are in load() below as the last parameter instead of "."
  // for development, use "/" to use the english original as
  // .qm files are stored in the base project directory.
  tor.load( QString("linpsk.") + QTextCodec::locale(), "/" );

  a.installTranslator( &tor );
  /* uncomment the following line, if you want a Windows 95 look*/
  // a.setStyle(WindowsStyle);
    
  LinPskApp *LinPsk=new LinPskApp();
  a.setMainWidget(LinPsk);
	LinPsk->setCaption(c);

  LinPsk->show();

  return a.exec();
}

==> linpsk_0.7.1-1.tar.gz: linpsk-0.7.1/linpsk/main.cpp <==
/***************************************************************************
                          main.cpp  -  description
                             -------------------
    begin                : Sam Nov 23 11:37:46 CET 2002
    copyright            : (C) 2002 by Volker Schroer
    email                : dl1ksv@gmx.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *   The PSK part is based on WinPSk 1.0 by Moe Wheatly, AE4JY             *                   
 ***************************************************************************/

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include <stdlib.h>
#include <qapplication.h>
#include <qmessagebox.h>
#include "linpsk.h"
#include "parameter.h"

Parameter settings;

int main(int argc, char *argv[])
{

        QApplication a( argc, argv );
            // Read Config - File
//      if (! settings.read_config())
//      QMessageBox::information(0,"LinPsk",
//        "LinPSK.config not found, using default values\nFile will be generated if you save the settings");

        LinPSK *w = new LinPSK(0,"LinPSK");
        w->show();
        return a.exec();

}
